########################################################################
# Introscope EPAgent Plugin Script                               
#                                                                      
# CA Wily Introscope(R) Version 9.7.1 Release 9.7.1.16
# Copyright (c) 2015 CA. All Rights Reserved.
# Introscope(R) is a registered trademark of CA.
#
########################################################################
# kstat.pl 
# --------
# This Plugin Script reports metrics based on Solaris
# kernel statistics available from the Solaris kstat perl library or
# the kstat command-line utility.
#
# Most of the logic resides in Wily::Kstat, which is a smart wrapper
# library around the Sun::Solaris:Kstat perl module and the Solaris
# kstat cmd-line utility.
#
# It takes 4 command line arguments:
# 1) class  regular expression that will match a kstat class
#       Default: all
# 2) module  regular expression that will match a kstat module
#       Default: all
# 3) name  regular expression that will match a kstat name
#       Default: all
# 4) statistic  regular expression that will match a kstat statistic
#       Default: all
#
########################################################################

use strict;

use FindBin;
use lib ("$FindBin::Bin", "$FindBin::Bin/../lib/perl");
use Getopt::Long;

use Wily::Kstat;
use Wily::PrintMetric;

$| = 1; # auto-flush STDOUT

##########
# Globals
##########
my $class     = '.';
my $module    = '.';
my $instance  = '.';
my $name      = '.';
my $statistic = '.';

my $regex         = 0;       # by default, cmd-line options are shell wildcards
my $printInstance = 0;       # by default, metric names don't have instance

#############################
# Parse Command-Line Options
#############################
GetOptions(
    'class=s'       => \$class,
    'module=s'      => \$module,
    'instance=s'    => \$instance,
    'name=s'        => \$name,
    'statistic=s'   => \$statistic,
    'regex'         => \$regex,
    'printInstance' => \$printInstance,
);

#######
# MAIN 
#######
Wily::Kstat::useRE($regex);

my $kstat = Wily::Kstat::getStats(class     => $class, 
								  module    => $module, 
								  instance  => $instance, 
								  name      => $name, 
								  statistic => $statistic);

Wily::Kstat::printStats(stats         => $kstat,
						printInstance => $printInstance);

